<?php
/**
 * PHPTemplate
 * Parses templates files using PHP as markup language.
 * You don't have to learn a new language because PHP is a template language by itself.
 *
 * @author Nando Vieira
 *
 * ===================================
 * index.php
 * ===================================
 *  <code>
 *      require_once 'PHPTemplate.class.php';
 *      $tpl = new PHPTemplate();
 *      $tpl->add('title', 'My Page title');
 *      $tpl->add('content', '<p>Here is my content!</p>');
 *      $tpl->load('footer', 'footer.tpl');
 *      $tpl->add('current_year', date('Y'));
 *      $tpl->display('template.tpl');
 *  </code>
 *
 * ===================================
 * template.tpl
 * ===================================
 * <code>
 *      <html>
 *          <head>
 *              <title><?=$title?></title>
 *          </head>
 *          <body>
 *            <h1><?=$title?></h1>
 *            <?=$content?>
 *            <?=$footer?>
 *          </body>
 *      </html>
 * </code>
 *
 * ===================================
 * footer.tpl
 * =================================== 
 * <code>
 *      <hr />
 *       2003-<?=$current_year?>, All rights reserved.
 * </code>
 */
class PHPTemplate{
    var $variables  = array();
    var $version    = '1.0';
    var $author     = 'Nando Vieira <nando[at]simplesideias.com.br>';
    var $gzip       = true;
    
    function PHPTemplate()
    {
        
    }
    
    /**
     * Displays the specified template.
     *
     * @param string $filename
     */
    function display($filename)
    {
        if ($this->gzip) ob_start('ob_gzhandler');
        echo $this->fetch($filename);
    }
    
    /**
     * Parses the specified template and returns its content.
     *
     * @param   string $___filename
     * @return  string
     */
    function fetch($___filename)
    {
        ob_start();
        extract($this->variables, EXTR_REFS | EXTR_OVERWRITE);
        require_once($___filename);
        $___content = ob_get_contents();
        ob_end_clean();
        
        return $___content;
    }
    
    /**
     * Gets the specified assigned variable.
     *
     * @param   string $name
     * @return  mixed
     */
    function get($name)
    {
        return $this->variables[$name];
    }
    
    /**
     * Assigns the variable $name.
     *
     * @param string    $name 
     * @param mixed     $value
     */
    function add($name, $value)
    {
        $this->variables[$name] = $value;
    }
    
    /**
     * Clears the specified variable.
     *
     * @param   string  $name
     */
    function clear($name)
    {
        unset($this->variables[$name]);
    }
    
    /**
     * Clears all variables.
     */
    function clearAll()
    {
        $this->variables = array();
    }
    
    /**
     * Assigns the specified variable $name with the content of $filename.
     *
     * @param   string  $name
     * @param   string  $filename
     * @return  string
     */
    function load($name, $filename)
    {
        if (!is_file($filename)) { $this->variables[$name] = "<strong>{$filename}</strong> not found."; return; }
        $content = $this->fetch($filename);
        $this->variables[$name] = $content;
        return $content;
    }
    
    /**
     * Parses the specified file $filename with an array $data.
     * Useful for parsing piece of code.
     *
     * @param   string  $filename
     * @param   array   $data
     * @return  string
     */
    function parse($filename, $data)
    {
        $tpl = new Template();
        foreach ($data as $k => $v)
            $tpl->add($k, $v);
        
        return $tpl->fetch($filename);
    }
}
?>